package com.angrist.simplecamera;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.text.SimpleDateFormat;
import java.util.Date;

import android.app.Activity;
import android.hardware.Camera;
import android.hardware.Camera.PictureCallback;
import android.hardware.Camera.PreviewCallback;
import android.os.Bundle;
import android.os.Environment;
import android.util.Log;
import android.view.Menu;
import android.view.View;
import android.view.WindowManager;
import android.widget.FrameLayout;
import android.widget.ImageButton;
import android.widget.Toast;

import com.angrist.simplecamera.R.id;

public class MainActivity extends Activity {
	private Camera mCamera;
	private CameraPreview mPreview;
	private Boolean savePictures;
// camera.setPreviewCallback(mPic); kanske fra tt f in previews
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		getWindow().addFlags(WindowManager.LayoutParams.FLAG_KEEP_SCREEN_ON); // Keep display turned on
		// Create instance of camera
		mCamera = getCameraInstance();
		if (mCamera == null) {
			Toast toast = Toast.makeText(getApplicationContext(),
					"Finns ingen kamera", Toast.LENGTH_LONG);
			toast.show();
		}
		// Create Preview view and set it as the content of activity
		mPreview = new CameraPreview(this, mCamera);
		FrameLayout preview = (FrameLayout) findViewById(id.camera_preview);
		preview.addView(mPreview);
		savePictures = false;
		mCamera.setPreviewCallback(mPic);

		// Listener on button
		ImageButton captureButton = (ImageButton) findViewById(id.cameraButton);
		captureButton.setOnClickListener(new View.OnClickListener() {

			@Override
			public void onClick(View v) {
				mCamera.takePicture(null, null, mPicture);
				
			}
		});
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}
	
	/** Helper class to open camera */
	public static Camera getCameraInstance() {
		Camera c = null;
		try {
			c = Camera.open();
		} catch (Exception e) {
			// camera is not available
		}
		return c;
	}

	/** Create a File for saving the image */
	private static File getOutputMediaFile() {
		File mediaStorageDir = new File(
				Environment
						.getExternalStoragePublicDirectory(Environment.DIRECTORY_PICTURES),
				"SimpleCameras");
		if (!mediaStorageDir.exists()) {
			if (!mediaStorageDir.mkdirs()) {
				Log.d("MAIN_ACTIVITY", "failed to create directory");
				return null;
			}
		}
		// Create mediafilename
		String timeStamp = new SimpleDateFormat("yyyMMdd_hhmmss")
				.format(new Date());
		File mediaFile;
		mediaFile = new File(mediaStorageDir.getPath() + File.separator
				+ "IMG_" + timeStamp + ".jpg");
		return mediaFile;
	}

	private PictureCallback mPicture = new PictureCallback() {
		@Override
		public void onPictureTaken(byte[] data, Camera camera) {
			File pictureFile = getOutputMediaFile();
			if (pictureFile == null) {
				Log.d("MAIN_ACTIVITY",
						"Error creating media file, check storage permission ");
				
				return;
			}
			try {
				FileOutputStream fos = new FileOutputStream(pictureFile);
				fos.write(data);
				fos.close();
			} catch (FileNotFoundException e) {
				// TODO fixa error mess
			} catch (IOException e) {
				// TODO fixa err mess
			}
			camera.startPreview(); // Restart after picture is taken
		}

	};
	private PreviewCallback mPic = new PreviewCallback(){
		@Override
		public void onPreviewFrame(byte[] data, Camera camera){
			if (savePictures){
				/*Toast toast = Toast.makeText(getApplicationContext(),
						"Tar kort", Toast.LENGTH_SHORT);
				toast.show();*/
				Log.d("PREVIEW_CALLBACK", "Tar kort nu");
				File pictureFile = getOutputMediaFile();
				if (pictureFile == null) {
					Log.d("MAIN_ACTIVITY",
							"Error creating media file, check storage permission ");
					
					return;
				}
				try {
					FileOutputStream fos = new FileOutputStream(pictureFile);
					fos.write(data);
					fos.close();
				} catch (FileNotFoundException e) {
					// TODO fixa error mess
				} catch (IOException e) {
					// TODO fixa err mess
				}
			}
		}
	};

}
